rpms/farsight/devel farsight-darth-vader.patch,NONE,1.1

Brian Pepple (bpepple) fedora-extras-commits at redhat.com
Fri May 2 13:04:10 UTC 2008


Author: bpepple

Update of /cvs/pkgs/rpms/farsight/devel
In directory cvs-int.fedora.redhat.com:/tmp/cvs-serv31699

Added Files:
	farsight-darth-vader.patch 
Log Message:
add patch

farsight-darth-vader.patch:

--- NEW FILE farsight-darth-vader.patch ---
--- plugins/rtp/rtpgstcodecs.c.orig	2008-05-02 11:56:09.000000000 +0100
+++ plugins/rtp/rtpgstcodecs.c	2008-05-02 11:57:22.000000000 +0100
@@ -2594,6 +2594,7 @@
     {
       if (is_payloader (walk->data))
       {
+        GstElement *filter;
         g_object_set (current_element, "pt", codec_association->codec->id,
             NULL);
         /* TODO find a better way to set the MTU, RTCP perhaps? */
@@ -2601,8 +2602,14 @@
         /* FIXME please don't hardcode me */
         g_object_set (current_element, "max_ptime", 20 * GST_MSECOND, NULL);
 
-        /* let's create our bin src ghostpad and link it to the payloader */
-        if (!create_ghost_pad (current_element, "src", codec_bin)) {
+        filter = gst_element_factory_make("capsfilter", NULL);
+        g_object_set (filter, "caps",
+          farsight_codec_to_gst_caps (codec_association->codec), NULL);
+        gst_bin_add (GST_BIN(codec_bin), filter);
+        gst_element_link (current_element, filter);
+
+        /* let's create our bin src ghostpad and link it to the filter */
+        if (!create_ghost_pad (filter, "src", codec_bin)) {
           g_warning ("Could not create payloader src ghost pad on the codec_bin"
               " for payload type %d", codec_id);
           gst_object_unref (codec_bin);




More information about the fedora-extras-commits mailing list